function [L, pca_para] = TDL_train(x,CountOfSampleEachClass,pars)
% TDL_train train the metric by TDL with input training data.
% Last updated: 2016/7/6
%
% Usage: 
% [L,pca_para]=TDL_train(x,CountOfSampleEachClass,pars);
%
% Input:
% x - Feature matrix of training set of size d x n, in which d is feature dimension and n is the number of samples. The samples are sorted by labels.
% CountOfSampleEachClass - a row vector containing the number of samples of each class, corresponding to the feature matrix
% pars.outdim - dimension of TDL output (default: 120)
% pars.alpha - weight of the push term in the objective function (ranged from 0 to 1, default: 0.2)
% pars.maxiter - max iteration time (default: 1000)
% pars.dem_pca - dimension of PCA output (default: n-1, n is the number of samples)
%
% Output:
% L - the learned metric M=L'*L
% pca_para.dim - reduced dimension of PCA
% pca_para.projection - projection matrix of PCA
if nargin<3
	pars.outdim = 120; % output dimension of TDL
	pars.alpha = 0.2; % weight of push term in objective function
	pars.maxiter = 1000; % max iteration count
	pars.dem_pca = size(x,2)-1; % number of samples minus 1
end
[L, pca_para] = TDL(x,CountOfSampleEachClass,pars);
end